@@ -115,10 +115,10 @@ PARAMETER_DEFINITION_EXCLUSIONS = {'CephPools': ['description',
                                                                'constraints'],
                                    # NOTE(anil): This is a temporary change and
                                    # will be removed once bug #1767070 properly
-                                   # fixed. OVN supports only VLAN and geneve
-                                   # for NeutronNetworkType. But VLAN tenant
-                                   # networks have a limited support in OVN.
-                                   # Till that is fixed, we restrict
+                                   # fixed. OVN supports only VLAN, geneve
+                                   # and flat for NeutronNetworkType. But VLAN
+                                   # tenant networks have a limited support
+                                   # in OVN. Till that is fixed, we restrict
                                    # NeutronNetworkType to 'geneve'.
                                    'NeutronNetworkType': ['description',
                                                           'default',
@@ -185,6 +185,10 @@ DEPLOYMENT_RESOURCE_TYPES = [
 
 VALID_ANSIBLE_UPGRADE_TAGS = [ 'common', 'validation', 'pre-upgrade' ]
 
+ANSIBLE_TASKS_YAMLS = [
+    './extraconfig/pre_network/boot_param_tasks.yaml'
+]
+
 def exit_usage():
     print('Usage %s <yaml file or directory>' % sys.argv[0])
     sys.exit(1)
@@ -738,13 +742,15 @@ def validate(filename, param_map):
         if filename.startswith('./roles/'):
             retval = validate_role_name(filename)
 
-        if filename.startswith('./roles/ComputeHCI.yaml'):
-            retval = validate_hci_computehci_role(filename, tpl)
+        if filename.startswith('./roles/ComputeHCI.yaml') or \
+                filename.startswith('./roles/ComputeHCIOvsDpdk.yaml'):
+            retval |= validate_hci_computehci_role(filename, tpl)
 
         if filename.startswith('./roles/ComputeOvsDpdk.yaml') or \
                 filename.startswith('./roles/ComputeSriov.yaml') or \
                 filename.startswith('./roles/ComputeOvsDpdkRT.yaml') or \
-                filename.startswith('./roles/ComputeSriovRT.yaml'):
+                filename.startswith('./roles/ComputeSriovRT.yaml') or \
+                filename.startswith('./roles/ComputeHCIOvsDpdk.yaml'):
             exclude = [
                 'OS::TripleO::Services::OVNController',
                 'OS::TripleO::Services::ComputeNeutronOvsAgent',
@@ -777,6 +783,8 @@ def validate(filename, param_map):
             retval = validate_nic_config_file(filename, tpl)
 
     except Exception:
+        if filename in ANSIBLE_TASKS_YAMLS:
+            return 0
         print(traceback.format_exc())
         return 1
     # yaml is OK, now walk the parameters and output a warning for unused ones
